@@ -1,7 +1,8 @@
 /*-------------------------------------------------------------------------
  *
- * Portions Copyright (c) 2007-2012, PostgreSQL Global Development Group
+ * Portions Copyright (c) 2017-2019, pg_bigm Development Group
  * Portions Copyright (c) 2013-2016, NTT DATA Corporation
+ * Portions Copyright (c) 2007-2012, PostgreSQL Global Development Group
  *
  * Changelog:
  *	 2013/01/09
@@ -17,8 +18,13 @@
 #include "access/gin.h"
 #include "access/gin_private.h"
 #include "access/itup.h"
+#if PG_VERSION_NUM >= 120000
+#include "access/relation.h"
+#endif
 #include "access/skey.h"
+#if PG_VERSION_NUM < 130000
 #include "access/tuptoaster.h"
+#endif
 #include "access/xlog.h"
 #if PG_VERSION_NUM > 90500
 #include "catalog/pg_am.h"
@@ -417,7 +423,11 @@ pg_gin_pending_stats(PG_FUNCTION_ARGS)
 	 * Construct a tuple descriptor for the result row. This must match this
 	 * function's pg_bigm--x.x.sql entry.
 	 */
+ #if PG_VERSION_NUM >= 120000
+	tupdesc = CreateTemplateTupleDesc(2);
+#else
 	tupdesc = CreateTemplateTupleDesc(2, false);
+#endif
 	TupleDescInitEntry(tupdesc, (AttrNumber) 1,
 					   "pages", INT4OID, -1, 0);
 	TupleDescInitEntry(tupdesc, (AttrNumber) 2,
